<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>{% firstof object.page_title objet.title %}</title>
  </head>
  <body>
    {% block content %}{% endblock content %}
  </body>
</html>
