# Generated by Django 3.2.13 on 2022-04-13 06:24

from django.db import migrations, models
import tinymce.models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('simpel_pages', '0005_block_imageblock_richtextblock'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='The groups this menu belongs to. A menu will get all permissions granted to each of their groups.', related_name='_simpel_pages_page_groups_+', to='auth.Group', verbose_name='groups'),
        ),
        migrations.AlterField(
            model_name='category',
            name='description',
            field=tinymce.models.HTMLField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='page',
            name='content',
            field=tinymce.models.HTMLField(blank=True, null=True, verbose_name='Content'),
        ),
        migrations.AlterField(
            model_name='richtextblock',
            name='text',
            field=tinymce.models.HTMLField(),
        ),
        migrations.AlterField(
            model_name='tag',
            name='description',
            field=tinymce.models.HTMLField(blank=True, null=True, verbose_name='Description'),
        ),
    ]
