import logging
import re

from django.conf import settings
from django.template.defaultfilters import slugify

import requests

logger = logging.getLogger(__name__)


def unique_slugify(instance, value, slug_field_name="slug", queryset=None, slug_separator="-"):
    """
    Calculates and stores a unique slug of ``value`` for an instance.

    ``slug_field_name`` should be a string matching the name of the field to
    store the slug in (and the field to check against for uniqueness).

    ``queryset`` usually doesn't need to be explicitly provided - it'll default
    to using the ``.all()`` queryset from the model's default manager.
    """
    slug_field = instance._meta.get_field(slug_field_name)

    slug = getattr(instance, slug_field.attname)
    slug_len = slug_field.max_length

    # Sort out the initial slug, limiting its length if necessary.
    slug = slugify(value)
    if slug_len:
        slug = slug[:slug_len]
    slug = _slug_strip(slug, slug_separator)
    original_slug = slug

    # Create the queryset if one wasn't explicitly provided and exclude the
    # current instance from the queryset.
    if queryset is None:
        queryset = instance.__class__._default_manager.all()
    if instance.pk:
        queryset = queryset.exclude(pk=instance.pk)

    # Find a unique slug. If one matches, at '-2' to the end and try again
    # (then '-3', etc).
    next = 2
    while not slug or queryset.filter(**{slug_field_name: slug}):
        slug = original_slug
        end = "%s%s" % (slug_separator, next)
        if slug_len and len(slug) + len(end) > slug_len:
            slug = slug[: slug_len - len(end)]
            slug = _slug_strip(slug, slug_separator)
        slug = "%s%s" % (slug, end)
        next += 1

    setattr(instance, slug_field.attname, slug)


def _slug_strip(value, separator="-"):
    """
    Cleans up a slug by removing slug separator characters that occur at the
    beginning or end of a slug.

    If an alternate separator is used, it will also replace any instances of
    the default '-' separator with the new separator.
    """
    separator = separator or ""
    if separator == "-" or not separator:
        re_sep = "-"
    else:
        re_sep = "(?:-|%s)" % re.escape(separator)
    # Remove multiple instances and if an alternate separator is provided,
    # replace the default '-' separator.
    if separator != re_sep:
        value = re.sub("%s+" % re_sep, separator, value)
    # Remove separator from the beginning and end of the slug.
    if separator:
        if separator != "-":
            re_sep = re.escape(separator)
        value = re.sub(r"^%s+|%s+$" % (re_sep, re_sep), "", value)
    return value


def get_ip(request):
    """
    Attempts to extract the IP number from the HTTP request headers.
    """
    key = "REMOTE_ADDR"
    meta = request.META

    # Lowercase keys
    simple_meta = {k.lower(): v for k, v in request.META.items()}
    ip = meta.get(key, simple_meta.get(key, "0.0.0.0"))
    return ip


def get_ip_location(ip):
    if settings.DEBUG:
        ip = "116.206.42.67"
    try:
        url = f"http://ip-api.com/json/{ip}"
        res = requests.get(
            url,
            headers={
                "Content-Type": "application/json",
                "User-Agent": "Mozilla/5.0",
            },
        )
        ip_data = res.json()
        ip_data.update(get_geo_location(ip_data["lat"], ip_data["lon"]))
        logger.info(ip_data)
        return ip_data
    except Exception as exc:
        logger.error(exc, exc_info=1)
        return None


def get_geo_location(lat: float, lon: float):
    res = requests.post(
        "https://geocode.arcgis.com/arcgis/rest/services/World/GeocodeServer/reverseGeocode",
        params={
            "f": "json",
            "location": f"{lon}, {lat}",
            "distance": 5000,
            "outSR": "",
        },
        headers={
            "Content-Type": "application/json",
        },
    )
    return res.json()
